@@ -1,6 +1,7 @@
 
 import argparse
 from pathlib import Path
+import os
 import shutil
 import subprocess as sp
 import sys
@@ -14,6 +15,26 @@ import referenceseeker.constants as rc
 import referenceseeker.util as util
 
 
+def check(db_path):
+    """Check if database directory exists, is accessible and contains necessary files."""
+
+    if(db_path is None):
+        sys.exit('ERROR: database directory not provided nor detected! Please provide a valid path to the database directory.')
+
+    if(not os.access(str(db_path), os.R_OK & os.X_OK)):
+        sys.exit(f'ERROR: database directory ({db_path}) not readable/accessible!')
+
+    file_names = [
+        'db.tsv',
+        'db.msh'
+    ]
+
+    for file_name in file_names:
+        path = db_path.joinpath(file_name)
+        if(not os.access(str(path), os.R_OK) or not path.is_file()):
+            sys.exit(f'ERROR: database file ({file_name}) not readable!')
+
+
 def init(args):
     try:
         cwd_path = Path(args.output).resolve()
@@ -33,42 +54,50 @@ def init(args):
         db_sketch_path = db_path.joinpath('db.msh')
         db_sketch_path.touch(mode=0o660)
         print('created database genome kmer sketch file (db.msh)')
-    except:
+    except Exception as e:
         print(f'Error: could not init database ({args.output}) in output directory ({args.db})!', file=sys.stderr)
-        raise
-        sys.exit(-1)
+        raise e
     print(f'\nSuccessfully initialized empty database at {db_path}')
     print("Use 'referenceseeker_db import' to import genomes into database")
 
 
-def import_genome(config, args):
+def import_genome(args):
     try:
         db_path = Path(args.db).resolve()
-        genome_path = Path(args.genome).resolve()
+        check(db_path)
         tmp_path = Path(tempfile.mkdtemp())
-        genome_suffix = genome_path.suffix.lower()
         genome_id = args.id
+        genome_path = Path(args.genome).resolve()
+        genome_suffix = genome_path.suffix.lower()
+        if(genome_suffix == '.gz'):
+            genome_suffix = Path(genome_path.stem).suffix
         if(genome_suffix in ['.fasta', '.fas', '.fsa', '.fna', '.fa']):
             # import fasta
-            with genome_path.open() as fh_in:
-                sequences = SeqIO.parse(fh_in, 'fasta')
-                test_sequences(sequences)
+            input_path = genome_path
+            genome_path = tmp_path.joinpath('genome.fasta')
+            with xopen(str(input_path), threads=0) as fh_in, genome_path.open('w') as fh_out:
+                sequences_in = SeqIO.parse(fh_in, 'fasta')
+                sequences = test_sequences(sequences_in)
+                for id, seq in sequences:
+                    fh_out.write(f'>{id}\n{seq}\n')
         elif(genome_suffix in ['.genbank', '.gbff', '.gbk', '.gb']):
             # import genbank
             input_path = genome_path
             genome_path = tmp_path.joinpath('genome.fasta')
-            with input_path.open() as fh_in, genome_path.open('w') as fh_out:
-                sequences = SeqIO.parse(fh_in, 'genbank')
-                test_sequences(sequences)
-                SeqIO.write(sequences, fh_out, 'fasta')
+            with xopen(str(input_path), threads=0) as fh_in, genome_path.open('w') as fh_out:
+                sequences_in = SeqIO.parse(fh_in, 'genbank')
+                sequences = test_sequences(sequences_in)
+                for id, seq in sequences:
+                    fh_out.write(f'>{id}\n{seq}\n')
         elif(genome_suffix in ['.embl', '.ebl', '.el']):
             # import embl
             input_path = genome_path
             genome_path = tmp_path.joinpath('genome.fasta')
-            with input_path.open() as fh_in, genome_path.open('w') as fh_out:
-                sequences = SeqIO.parse(fh_in, 'embl')
-                test_sequences(sequences)
-                SeqIO.write(sequences, fh_out, 'fasta')
+            with xopen(str(input_path), threads=0) as fh_in, genome_path.open('w') as fh_out:
+                sequences_in = SeqIO.parse(fh_in, 'embl')
+                sequences = test_sequences(sequences_in)
+                for id, seq in sequences:
+                    fh_out.write(f'>{id}\n{seq}\n')
         else:
             raise Exception(f'Unknown genome file extension ({genome_suffix})')
 
@@ -101,7 +130,6 @@ def import_genome(config, args):
         proc = sp.run(
             cmd,
             cwd=str(tmp_path),
-            env=config['env'],
             stdout=sp.PIPE,
             stderr=sp.PIPE,
             universal_newlines=True
@@ -125,7 +153,6 @@ def import_genome(config, args):
             proc = sp.run(
                 cmd,
                 cwd=str(tmp_path),
-                env=config['env'],
                 stdout=sp.PIPE,
                 stderr=sp.PIPE,
                 universal_newlines=True
@@ -142,27 +169,28 @@ def import_genome(config, args):
         with db_path.joinpath('db.tsv').open(mode='a') as fh:
             fh.write(f'{genome_id}\t{args.taxonomy}\t{args.status}\t{args.organism}\n')
     except Exception as e:
-        print(e)
         print(f'ERROR: could not import genome ({args.organism}/{args.genome}) into database ({args.db})!', file=sys.stderr)
-        sys.exit(-1)
-    print('\nSuccessfully imported genome ({args.organism}/{args.genome}) into database ({db_path})')
+        raise e
+    print(f'\nSuccessfully imported genome ({args.organism}/{args.genome}) into database ({db_path})')
 
 
-def test_sequences(sequences):
+def test_sequences(sequences_in):
     sequence_ids = set()
-    for record in sequences:
+    sequences = []
+    for record in sequences_in:
         if(len(record.seq) == 0):
             raise Exception(f'Record {record.id} with zero length sequence')
         if(record.id in sequence_ids):
             raise Exception(f'Duplicated record id: {record.id}')
         else:
+            sequences.append((record.id, str(record.seq)))
             sequence_ids.add(record.id)
+    return sequences
 
 
 def main():
     #  setup path and test if necessary 3rd party executables are available
-    config = {}
-    util.test_binaries(config)
+    util.test_binaries()
 
     # parse options and arguments
     parser = argparse.ArgumentParser(
@@ -197,7 +225,7 @@ def main():
     if(args.subcommand == 'init'):
         init(args)
     elif(args.subcommand == 'import'):
-        import_genome(config, args)
+        import_genome(args)
     else:
         parser.print_help()
         sys.exit('Error: no subcommand provided!')
