@@ -18,13 +18,12 @@ def run_mash(config, mash_output_path):
         proc = sp.run(
             cmd,
             cwd=str(config['tmp']),
-            env=config['env'],
             stdout=fh,
             stderr=sp.PIPE,
             universal_newlines=True
         )
         if(proc.returncode != 0):
-            sys.exit("ERROR: failed to execute Mash!\nexit=%d\ncmd=%s" % (proc.returncode, cmd))
+            sys.exit(f'ERROR: failed to execute Mash!\nexit={proc.returncode}\ncmd={cmd}')
 
 
 def parse_mash_results(config, mash_output_path):
