@@ -27,7 +27,7 @@ def read_reference_genomes(config):
     return ref_genomes
 
 
-def build_dna_fragments(genome_path, dna_fragments_path):
+def build_dna_fragments(config, genome_path, dna_fragments_path):
     """Build DNA fragments.
 
     :param genome_path: Path to source DNA Fasta file.
@@ -44,28 +44,19 @@ def build_dna_fragments(genome_path, dna_fragments_path):
             while len(sequence) > (rc.FRAGMENT_SIZE + rc.MIN_FRAGMENT_SIZE):  # forestall fragments shorter than MIN_FRAGMENT_SIZE
                 dna_fragment = sequence[:rc.FRAGMENT_SIZE]
                 dna_fragment_idx += 1
-                fh_out.write('>')
-                fh_out.write(str(dna_fragment_idx))
-                fh_out.write('\n')
-                fh_out.write(str(dna_fragment))
-                fh_out.write('\n')
+                fh_out.write(f'>{dna_fragment_idx}\n{dna_fragment}\n')
                 dna_fragments[dna_fragment_idx] = {
                     'id': dna_fragment_idx,
                     'length': len(dna_fragment)
                 }
-                sequence = sequence[rc.FRAGMENT_SIZE:]
+                sequence = sequence[config['sliding_window']:]
             dna_fragment = sequence
             dna_fragment_idx += 1
-            fh_out.write('>')
-            fh_out.write(str(dna_fragment_idx))
-            fh_out.write('\n')
-            fh_out.write(str(dna_fragment))
-            fh_out.write('\n')
+            fh_out.write(f'>{dna_fragment_idx}\n{dna_fragment}\n')
             dna_fragments[dna_fragment_idx] = {
                 'id': dna_fragment_idx,
                 'length': len(dna_fragment)
             }
-            # sequence = sequence[rc.FRAGMENT_SIZE:]
     return dna_fragments
 
 
@@ -79,7 +70,8 @@ def setup_configuration(args):
         'bidirectional': args.bidirectional,
         'crg': args.crg,
         'ani': args.ani,
-        'conserved_dna': args.conserved_dna
+        'conserved_dna': args.conserved_dna,
+        'sliding_window': args.sliding_window
     }
 
     base_dir = Path(__file__).parent.parent
@@ -89,7 +81,7 @@ def setup_configuration(args):
     return config
 
 
-def test_binaries(config):
+def test_binaries():
     """Test the proper installation of necessary 3rd party executables."""
 
     # test Mash
